@@ -7,7 +7,7 @@ EDA.norm <- function(fun,lower,upper,n = 30,maxiter,
   n_gen <- exexp$n_gen
   historical <- exexp$historical
   best <- list()
-  best[[1]] <- exexp$par[1,]
+  best[[1]] <- as.numeric(exexp$par[1,])
   counter <- 1
   while (n_gen < maxiter) {
     exexp <- EE.norm(pobl = exexp$par, fun = fun, n = n,
@@ -17,12 +17,12 @@ EDA.norm <- function(fun,lower,upper,n = 30,maxiter,
     n_gen <- exexp$n_gen
     historical <- c(historical,exexp$historical)
     counter <- counter + 1
-    best[[counter]] <- exexp$par[1,]
+    best[[counter]] <- as.numeric(exexp$par[1,])
   }
 
   par <- as.data.frame(exexp$par)
   value <- sapply(best, fun, ...)
-  sol <- best[[which.min(value)]]
+  sol <- as.numeric(best[[which.min(value)]])
   value <- min(value)
   return(list(sol = sol, par = par, value = value,
               historical = historical))
