@@ -24,7 +24,7 @@ EE.ecdf <- function(pobl,fun,n,k,tolerance,
       G <- G + 1
     }
   }
-  best_par <- P[order(Y)[1:n],]
+  best_par <- as.data.frame(P[order(Y)[1:n],])
   return(list(par = best_par, Y = Y,n_gen = n_gen,
               par_historical = P,
               historical = historical,n_gen2 = n_gen2))
