@@ -3,6 +3,7 @@ EE.mnorm <- function(pobl,fun,n,k,tolerance,
   error <- 1e10
   pobl <- as.data.frame(pobl)
   mu <- apply(pobl, 2, mean)
+  dim <- length(mu)
   sigma <- var(pobl)
   P <- rmvnorm(n = n, mean = mu, sigma = sigma)
   Y <- apply(P, 1, fun,...)
@@ -25,7 +26,11 @@ EE.mnorm <- function(pobl,fun,n,k,tolerance,
       G <- G + 1
     }
   }
-  best_par <- P[order(Y)[1:n],]
+  if(dim > 1){
+    best_par <- P[order(Y)[1:n],]
+  }else{
+    best_par <- as.data.frame(P[order(Y)[1:n],])
+  }
   return(list(par = best_par, Y = Y,n_gen = n_gen,
               par_historical = P,
               historical = historical,n_gen2 = n_gen2))
